Fallback

Struct Fallback 

pub struct Fallback<A, B> { /* private fields */ }
Try primary; on a failure another provider might survive, try secondary.

use io_harness::provider::Fallback;
use io_harness::{Anthropic, OpenRouter};

let provider = Fallback::new(OpenRouter::from_env()?, Anthropic::from_env()?);

Implementations

Source

impl<A: Provider, B: Provider> Fallback<A, B>

pub fn new(primary: A, secondary: B) -> Self

secondary answers when primary fails in a way it might survive.